@@ -41,6 +41,8 @@ static const R_CallMethodDef Callentries[] = {
     {"Cagmart3",      (DL_FUNC) &agmart3,      6},
     {"Cconcordance1", (DL_FUNC) &concordance1, 4}, 
     {"Cconcordance2", (DL_FUNC) &concordance2, 6}, 
+    {"Cconcordance3", (DL_FUNC) &concordance3, 6},
+    {"Cconcordance4", (DL_FUNC) &concordance4, 7},
     {"Ccoxcount1",    (DL_FUNC) &coxcount1,    2},
     {"Ccoxcount2",    (DL_FUNC) &coxcount2,    4},
     {"Ccoxexact",     (DL_FUNC) &coxexact,     8},
@@ -51,6 +53,7 @@ static const R_CallMethodDef Callentries[] = {
     {"Cgchol_inv",    (DL_FUNC) &gchol_inv,    2},
     {"Cpyears3b",     (DL_FUNC) &pyears3b,    10},
     {"Csurvfitci",    (DL_FUNC) &survfitci,   11},
+    {"Csurvfitkm",    (DL_FUNC) &survfitkm,    9},
     {"Csurvreg6",     (DL_FUNC) &survreg6,    15},
     {"Csurvreg7",     (DL_FUNC) &survreg7,    21},
     {"Csurvsplit",    (DL_FUNC) &survsplit,    3},
