@@ -155,6 +155,9 @@ SEXP gchol_inv(SEXP matrix, SEXP flag2);
 void init_doloop(int min, int max);
 int doloop      (int nloops, int *index);
 
+int *norisk(int n, double *time1, double *time2, double *status, 
+	    int *sort1, int *sort2, int *strata);
+
 void pyears1(Sint   *sn,      Sint   *sny,      Sint   *sdoevent, 
 	     double *sy,      double *wt,       
 	     Sint   *sedim,   Sint   *efac, 
@@ -188,10 +191,14 @@ void survdiff2(Sint   *nn,     Sint   *nngroup,    Sint   *nstrat,
 
 void survfit4(Sint *n,	Sint *dd,  double *x1,  double *x2) ;
 
-SEXP survfitci(SEXP ftime2,     SEXP sort12,  SEXP sort22, SEXP ntime2,
-                    SEXP status2, SEXP cstate2, SEXP wt2,  SEXP id2,
+SEXP survfitci(SEXP ftime2,       SEXP sort12,  SEXP sort22, SEXP ntime2,
+                    SEXP status2, SEXP cstate2, SEXP wt2,    SEXP id2,
                     SEXP p2,      SEXP i02,     SEXP sefit2) ;
   
+SEXP survfitkm(SEXP y2,     SEXP weight2,  SEXP sort12, SEXP sort22, 
+               SEXP type2,  SEXP id2,      SEXP nid2,   SEXP position2, 
+               SEXP influence2) ;
+
 SEXP survreg6(SEXP maxiter2,   SEXP nvarx,  SEXP y,
 	      SEXP ny2,        SEXP covar2, SEXP wtx,
 	      SEXP offset2,    SEXP beta2,  SEXP nstratx,
